module.exports = defineTest({
	description: 'supports bigint via acorn plugin'
});
